import {
  Metadata, Loader, Http, IDictionary, IEventParam, Config,
} from '@zeedhi/core';
import {
  TextInput, Tabs, TreeGridEditable, Form, Grid, GridEditable, Button,
  IComponentRender, DialogService, ModalService, Modal, Checkbox,
  LoadingService, Card,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

import { RichText } from '@zeedhi/zd-richtext';

import { EMFJS, RTFJS, WMFJS } from 'rtf.js';

export class Pla01300ModoPreparoController {
  private cardTextIsVisible = false;
  
  private appController = Loader.getInstance('AppController');
  
  private utilities = Loader.getInstance('Utilities');
  
  public gridEditController = Loader.getInstance('GridEditableController');
  
  public crudController = Loader.getInstance('CrudController');
  
  private cardModoPreparo = false;
  
  public newRow = false;
  
  public closeCard = false;
  
  public modalAddModoPrep!: Modal;
  
  public modalImportacao!: Modal;
  
  get controlImportButton() {
    let form: any;
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    try {
      if (tabPratos.activeTab === 3) form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      else if (tabPratos.activeTab === 4) form = Metadata.getInstance<Form>('FORM_LOCAL');
      else if (tabPratos.activeTab === 5) form = Metadata.getInstance<Form>('FORM_SERVICE');
      else if (tabPratos.activeTab === 6) form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      else if (tabPratos.activeTab === 7) form = Metadata.getInstance<Form>('FORM_REGIAO');

      if (form.validate()) return false;
      return true;
    } catch (e) {
      return false;
    }
  }
  
  public buttonDisable() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let form: any = '';
    let row: any = '';
    let grid: any = '';
    let button: any = '';

    if (tab.activeTab === 3) {
      if (document.getElementsByName('gridModoPreparoTipoCard').length > 0) {
        form = Metadata.getInstance<Form>('FORM_TIPOCARD');
        row = form.value;
        grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
        button = grid.getChildInstance('addButton');
        
        if (!row.CENTRAL || !row.TIPOCARD?.CDTIPOCARD) {
          button.disabled = true;
          grid.datasource.data = [];
        } else button.disabled = false;
      }
    } else if (tab.activeTab === 4) {
      if (document.getElementsByName('gridModoPreparoLocal').length > 0) {
        form = Metadata.getInstance<Form>('FORM_LOCAL');
        row = form.value;
        grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
        button = grid.getChildInstance('addButton');
        
        if (!row.BRANCH_LOCAL?.CDFILIAL) {
          button.disabled = true;
          grid.datasource.data = [];
        } else button.disabled = false;
      }
    } else if (tab.activeTab === 5) {
      if (document.getElementsByName('gridModoPreparoServico').length > 0) {
        form = Metadata.getInstance<Form>('FORM_SERVICE');
        row = form.value;
        grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
        button = grid.getChildInstance('addButton');
        
        if (!row.BRANCH_SERVICE?.CDFILIAL || !row.SERVICE?.CDSERVFILI) {
          button.disabled = true;
          grid.datasource.data = [];
        } else button.disabled = false;
      }
    } else if (tab.activeTab === 6) {
      if (document.getElementsByName('gridModoPreparoPadraoQualidade').length > 0) {
        form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
        // row = form.value;
        grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
        button = grid.getChildInstance('addButton');
        
        if (form.validate()) {
          button.disabled = false;
        } else {
          button.disabled = true;
          grid.datasource.data = [];
        }
      }
    } else if (tab.activeTab === 7) {
      if (document.getElementsByName('gridModoPreparoRegiao').length > 0) {
        form = Metadata.getInstance<Form>('FORM_REGIAO');
        row = form.value;
        grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
        button = grid.getChildInstance('addButton');
        
        if (!row.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE || !row.NMREGIAO?.CDREGIAO) {
          button.disabled = true;
          grid.datasource.data = [];
        } else button.disabled = false;
      }
    }
  }
  
  public setValuesCurrentForm() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let grid: any = '';
    
    if (tab.activeTab === 2) grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
    else if (tab.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
    else if (tab.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
    else if (tab.activeTab === 5) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
    else if (tab.activeTab === 6) grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
    else if (tab.activeTab === 7) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
    
    if (grid.datasource.currentRow) {
      const formAdd = Metadata.getInstance<Form>('formAddModoPreparo');
      const row = formAdd.value;

      if (tab.activeTab === 2) {
        row.NRPREP = grid.datasource.currentRow.NRPREPPRAT;
        row.IDPREP = grid.datasource.currentRow.IDPREPPRAT;
        row.NMRPREP = grid.datasource.currentRow.NMRPREPPRAT;
        row.TXPREP = grid.datasource.currentRow.TXPREPPRAT;
      } else if (tab.activeTab === 3) {
        row.NRPREP = grid.datasource.currentRow.NRPREPTPCARD;
        row.IDPREP = grid.datasource.currentRow.IDPREPTPCARD;
        row.NMRPREP = grid.datasource.currentRow.NMPREPTPCARD;
        row.TXPREP = grid.datasource.currentRow.TXPREPTPCARD;
      } else if (tab.activeTab === 4) {
        row.NRPREP = grid.datasource.currentRow.NRPREPFILI;
        row.IDPREP = grid.datasource.currentRow.IDPREPFILI;
        row.NMRPREP = grid.datasource.currentRow.NMRPREPFILI;
        row.TXPREP = grid.datasource.currentRow.TXPREPFILI;
      } else if (tab.activeTab === 5) {
        row.NRPREP = grid.datasource.currentRow.NRPREPSERV;
        row.IDPREP = grid.datasource.currentRow.IDPREPSERV;
        row.NMRPREP = grid.datasource.currentRow.NMRPREPSERV;
        row.TXPREP = grid.datasource.currentRow.TXPREPSERV;
      } else if (tab.activeTab === 6) {
        row.NRPREP = grid.datasource.currentRow.NRPREPPADQ;
        row.IDPREP = grid.datasource.currentRow.IDPREPPADQ;
        row.NMRPREP = grid.datasource.currentRow.NMPREPPADQ;
        row.TXPREP = grid.datasource.currentRow.TXPREPPADQ;
      } else if (tab.activeTab === 7) {
        row.NRPREP = grid.datasource.currentRow.NRPREPREGIAO;
        row.IDPREP = grid.datasource.currentRow.IDPREPREGIAO;
        row.NMRPREP = grid.datasource.currentRow.NMPREPREGIAO;
        row.TXPREP = grid.datasource.currentRow.TXPREPREGIAO;
      }
      // const text = Metadata.getInstance<RichText>('TXPREP');
      // text.content = row.TXPREP;
    }
  }
  
  public changeOverflowSelect() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let grid: any = '';
    
    if (tab.activeTab === 2) grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
    else if (tab.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
    else if (tab.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
    else if (tab.activeTab === 5) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
    else if (tab.activeTab === 6) grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
    else if (tab.activeTab === 7) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
    
    if (grid) {
      grid.columns[2].overflow = 2;
      this.setFilters();
    }
  }
  
  public onChangeModoPreparo() {
    this.closeCard = false;
    // this.addRow();
    // this.disableTrueButtons();
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    // let grid: GridEditable;
    
    let nameText = '';
    let nameKey = '';
    let gridName = '';
    
    if (tab.activeTab === 2) {
      nameText = 'TXPREPPRAT';
      nameKey = 'NRPREPPRAT';
      gridName = 'gridModoPreparoPadrao';
    } else if (tab.activeTab === 3) {
      nameText = 'TXPREPTPCARD';
      nameKey = 'NRPREPTPCARD';
      gridName = 'gridModoPreparoTipoCard';
    } else if (tab.activeTab === 4) {
      nameText = 'TXPREPFILI';
      nameKey = 'NRPREPFILI';
      gridName = 'gridModoPreparoLocal';
    } else if (tab.activeTab === 5) {
      nameText = 'TXPREPSERV';
      nameKey = 'NRPREPSERV';
      gridName = 'gridModoPreparoServico';
    } else if (tab.activeTab === 6) {
      nameText = 'TXPREPPADQ';
      nameKey = 'NRPREPPRAPADQUALI';
      gridName = 'gridModoPreparoPadraoQualidade';
    } else if (tab.activeTab === 7) {
      nameText = 'TXPREPREGIAO';
      nameKey = 'NRPREPPRAREGIAO';
      gridName = 'gridModoPreparoRegiao';
    }
    
    const grid = Metadata.getInstance<GridEditable>(gridName);
    const text = Metadata.getInstance<RichText>(nameText);
    const mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
      (a: any, b: any) => a[`${nameKey}`] === b[`${nameKey}`]);
    const currentRow = mergedRows.find(
      (el: IDictionary) => grid.datasource.currentRow !== undefined
        && el[`${nameKey}`] === grid.datasource.currentRow[`${nameKey}`],
    ) || grid.datasource.currentRow;
    if (currentRow !== undefined && currentRow[`${nameText}`]) {
      text.content = currentRow[`${nameText}`];
    } else text.content = '';
    
    this.cardTextVisible();
  }
  
  public defaultState(grid: GridEditable, cloneDs: any) {
    this.newRow = false;
    return grid.cancelEditedRows().then(() => {
      this.gridEditController.onInlineEdit({ component: grid });
      return cloneDs.get();
    });
  }
  
  public formatDatasourceModoPreparo(grid: GridEditable) {
    grid.datasource.loading = true;
    
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let textField: string = '';
    
    if (tab.activeTab === 2) textField = 'TXPREPPRAT';
    else if (tab.activeTab === 3) textField = 'TXPREPTPCARD';
    else if (tab.activeTab === 4) textField = 'TXPREPFILI';
    else if (tab.activeTab === 5) textField = 'TXPREPSERV';
    else if (tab.activeTab === 6) textField = 'TXPREPPADQ';
    else if (tab.activeTab === 7) textField = 'TXPREPREGIAO';
    
    const dataset = grid.datasource.data;
    const dataPromises = dataset.map((data: IDictionary) => this.formatText(data[`${textField}`]));
    Promise.all(dataPromises).then((responses) => {
      for (let i = 0; i < dataset.length; i += 1) {
        dataset[i][`${textField}`] = responses[i];
      }
      grid.datasource.updateData(dataset);
      // grid.datasource = cloneDs;
      grid.datasource.loading = false;
    });
  }
    
  public async setFilters() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    
    let grid: any = '';
    let form: any = '';
    let conditions: any = [];
    
    if (tab.activeTab === 2) {
      if (document.getElementsByName('gridModoPreparoPadrao').length > 0) {
        grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
        conditions = [
          {
            name: 'CDPRATO',
            operator: '=',
            value: currentRow.CDPRATO,
          },
          {
            name: 'CDFILAUXPRAT',
            operator: '=',
            value: currentRow.CDFILAUXPRAT,
          },
        ];
        
        grid.datasource.filter = conditions;
        
        await grid.datasource.get().then(() => {
          this.formatDatasourceModoPreparo(grid);
        });
      }
    } else if (tab.activeTab === 3) {
      if (document.getElementsByName('gridModoPreparoTipoCard').length > 0) {
        grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
        form = Metadata.getInstance<Form>('FORM_TIPOCARD');
        if (form.validate()) {
          conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'CDTIPOCARD',
              operator: '=',
              value: form.value.TIPOCARD.CDTIPOCARD,
            },
            {
              name: 'CDFILCENTPME',
              operator: '=',
              value: form.value.CENTRAL,
            },
          ];
          
          grid.datasource.filter = conditions;
          
          await grid.datasource.get().then(() => {
            this.formatDatasourceModoPreparo(grid);
          });
        } else {
          grid.datasource.filter = [];
          this.utilities.showAlert('alert', 'A Central e o Tipo de Cardápio deve ser informado.', 'error');
        }
      }
    } else if (tab.activeTab === 4) {
      if (document.getElementsByName('gridModoPreparoLocal').length > 0) {
        grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
        form = Metadata.getInstance<Form>('FORM_LOCAL');
        if (form.validate()) {
          conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'CDFILIAL',
              operator: '=',
              value: form.value.BRANCH_LOCAL.CDFILIAL,
            },
          ];
          
          grid.datasource.filter = conditions;
          
          await grid.datasource.get().then(() => {
            this.formatDatasourceModoPreparo(grid);
          });
        } else {
          grid.datasource.filter = [];
          this.utilities.showAlert('alert', 'Unidade deve ser informado.', 'error');
        }
      }
    } else if (tab.activeTab === 5) {
      if (document.getElementsByName('gridModoPreparoServico').length > 0) {
        grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
        form = Metadata.getInstance<Form>('FORM_SERVICE');
        if (form.validate()) {
          conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'CDFILIAL',
              operator: '=',
              value: form.value.BRANCH_SERVICE.CDFILIAL,
            },
            {
              name: 'CDSERVFILI',
              operator: '=',
              value: form.value.SERVICE.CDSERVFILI,
            },
          ];
          
          grid.datasource.filter = conditions;
          
          await grid.datasource.get().then(() => {
            this.formatDatasourceModoPreparo(grid);
          });
        } else {
          grid.datasource.filter = [];
          this.utilities.showAlert('alert', 'Unidade e serviço devem ser informados.', 'error');
        }
      }
    } else if (tab.activeTab === 6) {
      if (document.getElementsByName('gridModoPreparoPadraoQualidade').length > 0) {
        form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
        grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
        if (form.validate()) {
          conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'NRPADRAOQUALIDADE',
              operator: '=',
              value: form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE,
            },
          ];
          
          grid.datasource.filter = conditions;
          
          await grid.datasource.get().then(() => {
            this.formatDatasourceModoPreparo(grid);
          });
        } else {
          grid.datasource.filter = [];
          this.utilities.showAlert('alert', 'O Padrão de Qualidade deve ser informado.', 'error');
        }
      }
    } else if (tab.activeTab === 7) {
      if (document.getElementsByName('gridModoPreparoRegiao').length > 0) {
        grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
        form = Metadata.getInstance<Form>('FORM_REGIAO');
        if (form.validate()) {
          conditions = [
            {
              name: 'CDPRATO',
              operator: '=',
              value: currentRow.CDPRATO,
            },
            {
              name: 'CDFILAUXPRAT',
              operator: '=',
              value: currentRow.CDFILAUXPRAT,
            },
            {
              name: 'NRPADRAOQUALIDADE',
              operator: '=',
              value: form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE,
            },
            {
              name: 'CDREGIAO',
              operator: '=',
              value: form.value.NMREGIAO.CDREGIAO,
            },
          ];
          
          grid.datasource.filter = conditions;
          
          await grid.datasource.get().then(() => {
            this.formatDatasourceModoPreparo(grid);
          });
        } else {
          grid.datasource.filter = [];
          this.utilities.showAlert('alert', 'Padrão de Qualidade/Região devem ser informados.', 'error');
        }
      }
    }
  }
  
  private async createModalAdd() {
    this.modalAddModoPrep = await ModalService.createFromJsonPost('',
      { jsonPath: 'planejamento/prato/modoPreparo/modals/modo_preparo_add' });
  }

  public closeModalAdd() {
    this.setFilters();
    this.modalAddModoPrep.hide();
    this.modalAddModoPrep.destroy();
    this.modalAddModoPrep = this.utilities.modalEmpty;
  }
  
  public checkFiltersAdd() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let form: Form;
    let filial;
    let padrQual;
    
    if (tab.activeTab === 3) {
      form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const central = form.value.CENTRAL;
      const cardapio = form.value.TIPOCARD;
      if (central !== null && cardapio !== null) this.addRow();
      else this.utilities.showAlert('alert', 'A Central e o Tipo de Cardápio devem ser informados.', 'error');
    } else if (tab.activeTab === 4) {
      form = Metadata.getInstance<Form>('FORM_LOCAL');
      filial = form.value.BRANCH_LOCAL;
      if (filial !== null) this.addRow();
      else this.utilities.showAlert('alert', 'Unidade deve ser informado.', 'error');
    } else if (tab.activeTab === 5) {
      form = Metadata.getInstance<Form>('FORM_SERVICE');
      filial = form.value.BRANCH_SERVICE;
      const servico = form.value.SERVICE;
      if (filial && servico) this.addRow();
      else this.utilities.showAlert('alert', 'Unidade e serviço devem ser informados.', 'error');
    } else if (tab.activeTab === 6) {
      form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      padrQual = form.value.NMPADRAOQUALIDADE;
      if (padrQual) this.addRow();
      else this.utilities.showAlert('alert', 'O Padrão de Qualidade deve ser informado.', 'error');
    } else if (tab.activeTab === 7) {
      form = Metadata.getInstance<Form>('FORM_REGIAO');
      padrQual = form.value.NMPADRAOQUALIDADE;
      const regiao = form.value.NMREGIAO;
      if (padrQual && regiao) this.addRow();
      else this.utilities.showAlert('alert', 'Padrão de Qualidade/Região devem ser informados.', 'error');
    }
  }
  
  public addRow() {
    if (!this.modalAddModoPrep) {
      this.createModalAdd().then(() => {
        this.modalAddModoPrep.show();
      });
    } else {
      this.modalAddModoPrep.show();
      this.setValuesCurrentForm();
    }
  }
  
  public saveModoPreparo({ component }: IEventParam<Button>) {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    let formAdd: Form;
    
    if (component.name === 'salvarModoPrepImportar') formAdd = Metadata.getInstance<Form>('formModoPreparoImport');
    else formAdd = Metadata.getInstance<Form>('formAddModoPreparo');
    const editedRows = formAdd.value;
    
    let form: any = '';
    let filial: any = '';
    let servico: any = '';
    let cardapio: any = '';
    let padrQual: any = '';
    let regiao: any = '';
    let receita: any = '';
    
    const text = Metadata.getInstance<RichText>('TXPREP');
    editedRows.TXPREP = text?.content;
    
    editedRows.CDFILCENTPME = this.appController.getCdCentral();
    
    if (tab.activeTab === 2) {
      receita = 'P';
      editedRows.NRPREPPRAT = editedRows.NRPREP;
      editedRows.IDPREPPRAT = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMRPREPPRAT = editedRows.NMRPREP;
      editedRows.TXPREPPRAT = editedRows.TXPREP;
    } else if (tab.activeTab === 3) {
      form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      receita = 'C';
      editedRows.CDFILCENTPME = form.value.CENTRAL;
      cardapio = form.value.TIPOCARD.CDTIPOCARD;
      editedRows.NRPREPTPCARD = editedRows.NRPREP;
      editedRows.IDPREPTPCARD = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMPREPTPCARD = editedRows.NMRPREP;
      editedRows.TXPREPTPCARD = editedRows.TXPREP;
    } else if (tab.activeTab === 4) {
      form = Metadata.getInstance<Form>('FORM_LOCAL');
      receita = 'L';
      filial = form.value.BRANCH_LOCAL.CDFILIAL;
      editedRows.NRPREPFILI = editedRows.NRPREP;
      editedRows.IDPREPFILI = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMRPREPFILI = editedRows.NMRPREP;
      editedRows.TXPREPFILI = editedRows.TXPREP;
    } else if (tab.activeTab === 5) {
      form = Metadata.getInstance<Form>('FORM_SERVICE');
      receita = 'S';
      filial = form.value.BRANCH_SERVICE.CDFILIAL;
      servico = form.value.SERVICE.CDSERVFILI;
      editedRows.NRPREPSERV = editedRows.NRPREP;
      editedRows.IDPREPSERV = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMRPREPSERV = editedRows.NMRPREP;
      editedRows.TXPREPSERV = editedRows.TXPREP;
    } else if (tab.activeTab === 6) {
      form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      receita = 'Q';
      padrQual = form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
      editedRows.NRPREPPADQ = editedRows.NRPREP;
      editedRows.IDPREPPADQ = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMPREPPADQ = editedRows.NMRPREP;
      editedRows.TXPREPPADQ = editedRows.TXPREP;
    } else if (tab.activeTab === 7) {
      form = Metadata.getInstance<Form>('FORM_REGIAO');
      receita = 'R';
      padrQual = form.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
      regiao = form.value.NMREGIAO.CDREGIAO;
      editedRows.NRPREPREGIAO = editedRows.NRPREP;
      editedRows.IDPREPREGIAO = editedRows.IDPREP === undefined ? '2' : editedRows.IDPREP;
      editedRows.NMPREPREGIAO = editedRows.NMRPREP;
      editedRows.TXPREPREGIAO = editedRows.TXPREP;
    }
    
    editedRows.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
    editedRows.CDPRATO = currentRow.CDPRATO;
    editedRows.TIPO = receita;
    editedRows.CDFILIAL = filial !== '' ? filial : null;
    editedRows.CDSERVFILI = servico !== '' ? servico : null;
    editedRows.CDTIPOCARD = cardapio !== '' ? cardapio : null;
    editedRows.NRPADRAOQUALIDADE = padrQual !== '' ? padrQual : null;
    editedRows.CDREGIAO = regiao !== '' ? regiao : null;

    if (tab.activeTab === 2) editedRows.NRPREPPRAT = editedRows.NRPREPPRAT !== undefined ? editedRows.NRPREPPRAT : '';
    if (tab.activeTab === 3) editedRows.NRPREPTPCARD = editedRows.NRPREPTPCARD !== undefined ? editedRows.NRPREPTPCARD : '';
    if (tab.activeTab === 4) editedRows.NRPREPFILI = editedRows.NRPREPFILI !== undefined ? editedRows.NRPREPFILI : '';
    if (tab.activeTab === 5) editedRows.NRPREPSERV = editedRows.NRPREPSERV !== undefined ? editedRows.NRPREPSERV : '';
    if (tab.activeTab === 6) editedRows.NRPREPPADQ = editedRows.NRPREPPADQ !== undefined ? editedRows.NRPREPPADQ : '';
    if (tab.activeTab === 7) editedRows.NRPREPREGIAO = editedRows.NRPREPREGIAO !== undefined ? editedRows.NRPREPREGIAO : '';

    if ((editedRows.TXPREPPRAT !== null && editedRows.TXPREPPRAT !== undefined)
        || (editedRows.TXPREPFILI !== null && editedRows.TXPREPFILI !== undefined)
        || (editedRows.TXPREPSERV !== null && editedRows.TXPREPSERV !== undefined)
          || (editedRows.TXPREPTPCARD !== null && editedRows.TXPREPTPCARD !== undefined)
          || (editedRows.TXPREPPADQ !== null && editedRows.TXPREPPADQ !== undefined)
          || (editedRows.TXPREPREGIAO !== null && editedRows.TXPREPREGIAO !== undefined)) {
      LoadingService.show(' ');
      Http.post('/modoPreparo/save', { editedRows }).then(() => {
        this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
        if (component.name === 'salvarModoPrepImportar') this.closeModalImportacao();
        else this.closeModalAdd();
      }).catch((error: string) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      }).finally(() => {
        this.setFilters();
        // if (component.name !== 'salvarModoPrepImportar') this.disableTrueButtons();
        LoadingService.hide();
      });
    } else this.utilities.showAlert('alert', 'Obrigatório preenchimento do Texto.', 'error');
  }
  
  public saveGrid() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    let grid: any = '';
    let form: any = '';
    let filial: any = '';
    let servico: any = '';
    let cardapio: any = '';
    let central: any = '';
    let padrqual: any = '';
    let regiao: any = '';
    let receita: any = '';
    let countAtivo = 0;
    let mergedRows = [];
    
    if (tab.activeTab === 2) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadrao');
      receita = 'P';
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPPRAT === b.NRPREPPRAT);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPPRAT === '1') countAtivo += 1;
      });
    } else if (tab.activeTab === 3) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoTipoCard');
      form = Metadata.getInstance<Form>('FORM_TIPOCARD');
      receita = 'C';
      cardapio = form.value.TIPOCARD.CDTIPOCARD;
      central = form.value.CENTRAL;
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPTPCARD === b.NRPREPTPCARD);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPTPCARD === '1') countAtivo += 1;
      });
    } else if (tab.activeTab === 4) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoLocal');
      form = Metadata.getInstance<Form>('FORM_LOCAL');
      receita = 'L';
      filial = form.value.BRANCH_LOCAL.CDFILIAL;
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPFILI === b.NRPREPFILI);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPFILI === '1') countAtivo += 1;
      });
    } else if (tab.activeTab === 5) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoServico');
      form = Metadata.getInstance<Form>('FORM_SERVICE');
      receita = 'S';
      filial = form.value.BRANCH_SERVICE.CDFILIAL;
      servico = form.value.SERVICE.CDSERVFILI;
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPSERV === b.NRPREPSERV);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPSERV === '1') countAtivo += 1;
      });
    } else if (tab.activeTab === 6) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadraoQualidade');
      form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      receita = 'Q';
      padrqual = form.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPPRAPADQUALI === b.NRPREPPRAPADQUALI);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPPADQ === '1') countAtivo += 1;
      });
    } else if (tab.activeTab === 7) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoRegiao');
      form = Metadata.getInstance<Form>('FORM_REGIAO');
      receita = 'R';
      padrqual = form.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      regiao = form.value.NMREGIAO?.CDREGIAO;
      mergedRows = this.utilities.merge(grid.getEditedRows(), grid.datasource.data,
        (a: any, b: any) => a.NRPREPPRAREGIAO === b.NRPREPPRAREGIAO);
      mergedRows.forEach((el: IDictionary) => {
        if (el.IDPREPREGIAO === '1') countAtivo += 1;
      });
    }
    
    if (countAtivo > 1) {
      this.utilities.showAlert('alert', 'É necessário selecionar pelo menos e apenas um registro como ativo.', 'error');
    } else {
      const editedRows: IDictionary = grid.getEditedRows();
      editedRows.forEach((row: IDictionary) => {
        row.CDFILCENTPME = central !== '' ? central : this.appController.getCdCentral();
        row.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
        row.CDPRATO = currentRow.CDPRATO;
        row.TIPO = receita;
        row.CDFILIAL = filial !== '' ? filial : null;
        row.CDSERVFILI = servico !== '' ? servico : null;
        row.CDTIPOCARD = cardapio !== '' ? cardapio : null;
        row.NRPADRAOQUALIDADE = padrqual !== '' ? padrqual : null;
        row.CDREGIAO = regiao !== '' ? regiao : null;
      });
      
      if (editedRows.length > 0) {
        Http.post('/modoPreparo/save', { editedRows }).then(() => {
          this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
          this.gridEditController.defaultState(grid).then(() => {
            const toolbarSlot = grid.toolbarSlot;
            toolbarSlot.forEach((e: IComponentRender) => {
              if (e.name === 'cancelButton') e.disabled = true;
              if (e.name === 'saveButton') e.disabled = true;
            });
            this.setFilters();
          });
        }).catch((error: string) => {
          this.utilities.showAlert('alert', `pme::${error}`, 'error');
        });
      } else {
        this.gridEditController.defaultState(grid).then(() => {
          const toolbarSlot = grid.toolbarSlot;
          toolbarSlot.forEach((e: IComponentRender) => {
            if (e.name === 'cancelButton') e.disabled = true;
            if (e.name === 'saveButton') e.disabled = true;
          });
          this.setFilters();
        });
      }
    }
  }
  
  public cancelEditing() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let grid: any = '';

    if (tab.activeTab === 2) grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
    else if (tab.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
    else if (tab.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
    else if (tab.activeTab === 5) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
    else if (tab.activeTab === 6) grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
    else if (tab.activeTab === 7) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
    
    if (grid.editing) {
      this.gridEditController.defaultState(grid).then(() => {
        const toolbarSlot = grid.toolbarSlot;
        toolbarSlot.forEach((e: IComponentRender) => {
          if (e.name === 'cancelButton') e.disabled = true;
          if (e.name === 'saveButton') e.disabled = true;
        });
        
        this.setFilters();
      });
    }
  }
  
  public activeEditing() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let grid: any = '';

    if (tab.activeTab === 2) grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
    else if (tab.activeTab === 3) grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
    else if (tab.activeTab === 4) grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
    else if (tab.activeTab === 5) grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
    else if (tab.activeTab === 6) grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
    else if (tab.activeTab === 7) grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
    
    const toolbarSlot = grid.toolbarSlot;
    toolbarSlot.forEach((e: IComponentRender) => {
      if (e.name === 'cancelButton') e.disabled = false;
      if (e.name === 'saveButton') e.disabled = false;
    });
  }
  
  public deleteCheckedRows() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    let grid: any = '';
    let dataSourceName: any = '';

    if (tab.activeTab === 2) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoPadrao');
      dataSourceName = 'prepprapad';
    } else if (tab.activeTab === 3) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoTipoCard');
      dataSourceName = 'preppratpcard';
    } else if (tab.activeTab === 4) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoLocal');
      dataSourceName = 'prepprafil';
    } else if (tab.activeTab === 5) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoServico');
      dataSourceName = 'preppraser';
    } else if (tab.activeTab === 6) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoPadraoQualidade');
      dataSourceName = 'prepprapadquali';
    } else if (tab.activeTab === 7) {
      grid = Metadata.getInstance<Grid>('gridModoPreparoRegiao');
      dataSourceName = 'preppraregiao';
    }
    const checkedRows = grid.selectedRows;
    if (checkedRows.length === 0) this.utilities.showAlert('alert', 'Nenhum registro selecionado.', 'warning');
    else {
      DialogService.show({
        name: 'delete',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir os registros?',
        buttons: [
          {
            name: 'yesDelete',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.delete(checkedRows, dataSourceName, grid) },
            outline: true,
          },
          {
            name: 'noDelete',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }
  
  public delete(checkedRows: any, dataSourceName: any, grid: any) {
    LoadingService.show(' ');
    const button = Metadata.getInstance<Button>('yesDelete');
    this.utilities.activeLoadingButton(button);
    this.crudController.deleteRows(checkedRows, dataSourceName).then(() => {
      grid.cancelEditedRows();
      grid.selectedRows = [];
      this.utilities.disableLoadingButton(button);
      this.utilities.showAlert('alertError', 'Excluído com sucesso!', 'success');
      this.setFilters();
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      DialogService.hide();
      LoadingService.hide();
    });
  }
  
  private async createModalImportacao() {
    this.modalImportacao = await ModalService.createFromJsonPost('',
      { jsonPath: 'planejamento/prato/modoPreparo/modals/modo_preparo_importar' });
  }
  
  public closeModalImportacao() {
    this.modalImportacao.destroy();
    this.modalImportacao = this.utilities.modalEmpty;
  }
  
  public openModalImportacao() {
    if (!this.modalImportacao) {
      this.createModalImportacao().then(() => {
        this.modalImportacao.show();
      });
    } else {
      this.modalImportacao.show();
    }
  }
  
  public get setFilterImport() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const form = Metadata.getInstance<Form>('formUnidade');
    const unidade = form.value.UNIDADEFORM.CDFILIAL;
    const nivelMax = (Config.masks.plateMask as PmeMask).nivelMax;
    
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade || 'P',
      },
      {
        name: 'CDPRATO',
        operator: '=',
        value: currentRow.CDPRATO,
      },
      {
        name: 'CDNVPRATO',
        operator: '=',
        value: nivelMax,
      },
    ];
    
    return conditions;
    // component.datasource.filter = conditions;
    // component.datasource.get();
  }
  
  public setTextImport() {
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    const formReceita = Metadata.getInstance<Form>('formReceitasImport');
    const currentRow = formReceita.value.RECEITAS;
    
    let form: any;
    let filial: any;
    let servico: any;
    let central: any;
    let cardapio: any;
    let padrqual: any;
    let regiao: any;
    let receita: any;
    
    if (currentRow !== null) {
      currentRow.CDFILCENTPME = this.appController.getCdCentral();
      if (tab.activeTab === 2) {
        filial = null;
        servico = null;
        central = null;
        cardapio = null;
        padrqual = null;
        regiao = null;
        receita = 'P';
      } else if (tab.activeTab === 3) {
        form = Metadata.getInstance<Form>('FORM_TIPOCARD');
        filial = null;
        servico = null;
        central = form.value.CDCENTRAL;
        cardapio = form.value.TIPOCARD?.CDTIPOCARD;
        padrqual = null;
        regiao = null;
        receita = 'C';
      } else if (tab.activeTab === 4) {
        form = Metadata.getInstance<Form>('FORM_LOCAL');
        filial = form.value.BRANCH_LOCAL?.CDFILIAL;
        servico = null;
        central = null;
        cardapio = null;
        padrqual = null;
        regiao = null;
        receita = 'L';
      } else if (tab.activeTab === 5) {
        form = Metadata.getInstance<Form>('FORM_SERVICE');
        filial = form.value.BRANCH_SERVICE?.CDFILIAL;
        servico = form.value.SERVICE?.CDSERVFILI;
        central = null;
        cardapio = null;
        padrqual = null;
        regiao = null;
        receita = 'S';
      } else if (tab.activeTab === 6) {
        form = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
        padrqual = form.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
        regiao = null;
        filial = null;
        servico = null;
        central = null;
        cardapio = null;
        receita = 'Q';
      } else if (tab.activeTab === 7) {
        form = Metadata.getInstance<Form>('FORM_REGIAO');
        padrqual = form.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
        regiao = form.value.NMREGIAO?.CDREGIAO;
        central = null;
        cardapio = null;
        filial = null;
        servico = null;
        receita = 'R';
      }
      
      Http.post('/modoPreparo/returnTextImport', {
        currentRow, filial, servico, receita, central, cardapio, padrqual, regiao,
      }).then((result) => {
        const text = Metadata.getInstance<RichText>('TXPREP');
        const responsavel = Metadata.getInstance<TextInput>('NMRPREP');
        const resultText = result.data.dataset.result[0];
        this.formatText(resultText.TXPREPARO).then((retorno) => {
          text.content = retorno;
          responsavel.value = resultText.NMPREPARO;
        });
      });
    }
  }
  
  public setIdAtivo({ component }: IEventParam<Checkbox>) {
    if (component.value === undefined || component.value === '' || component.value === null) component.value = '1';
  }
  
  public disableFalseButtons() {
    const cancel = Metadata.getInstance<Button>('cancelButtonModoPreparo');
    const save = Metadata.getInstance<Button>('saveButtonModoPreparo');
    
    cancel.disabled = false;
    save.disabled = false;
  }
  
  public disableTrueButtons() {
    const cancel = Metadata.getInstance<Button>('cancelButtonModoPreparo');
    const save = Metadata.getInstance<Button>('saveButtonModoPreparo');
    
    cancel.disabled = true;
    save.disabled = true;
  }
  
  public stringToArrayBuffer(str: string) {
    const buffer = new ArrayBuffer(str.length);
    const bufferView = new Uint8Array(buffer);
    for (let i = 0; i < str.length; i += 1) {
      bufferView[i] = str.charCodeAt(i);
    }
    return buffer;
  }
  
  public async formatText(text: string) {
    let result = '';
    if (`${text}`.indexOf('rtf') >= 0) {
      RTFJS.loggingEnabled(false);
      WMFJS.loggingEnabled(false);
      EMFJS.loggingEnabled(false);
      const doc = new RTFJS.Document(this.stringToArrayBuffer(text), {});
      // const meta = doc.metadata();
      await doc.render().then((htmlElements) => {
        htmlElements.forEach((div) => {
          result += div.outerHTML;
        });
      }).catch((error) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      });
    } else if (text && `${text}`.indexOf('<p>') === -1) {
      const lines = text.split(/\n/g);
      for (let i = 0; i < lines.length; i += 1) {
        result += `<p>${lines[i]}</p>`;
      }
    } else result = text;
    return result;
  }
  
  get gridColsReturnValue(): number {
    return this.cardTextIsVisible ? 5 : 12;
  }
  
  get textColsReturnValue(): number {
    return this.cardTextIsVisible ? 7 : 12;
  }
  
  private cardTextVisible() {
    let card: any = '';
    let grid: any = '';
    const tab = Metadata.getInstance<Tabs>('tabPratos');
    if (tab.activeTab === 2) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadrao');
      card = Metadata.getInstance<Card>('cardTextModoPreparoPadrao');
    } else if (tab.activeTab === 3) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoTipoCard');
      card = Metadata.getInstance<Card>('cardTextModoPreparoTpCard');
    } else if (tab.activeTab === 4) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoLocal');
      card = Metadata.getInstance<Card>('cardTextModoPreparoLocal');
    } else if (tab.activeTab === 5) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoServico');
      card = Metadata.getInstance<Card>('cardTextModoPreparoServico');
    } else if (tab.activeTab === 6) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadraoQualidade');
      card = Metadata.getInstance<Card>('cardTextModoPreparoPadQual');
    } else if (tab.activeTab === 7) {
      grid = Metadata.getInstance<GridEditable>('gridModoPreparoRegiao');
      card = Metadata.getInstance<Card>('cardTextModoPreparoRegiao');
    }
    
    try {
      if (Object.keys(grid.datasource.currentRow).length > 0 && !grid.datasource.loading && !grid.editing) {
        card.isVisible = true;
        this.cardTextIsVisible = true;
      } else {
        card.isVisible = false;
        this.cardTextIsVisible = false;
      }
    } catch (Error) {
      card.isVisible = false;
      this.cardTextIsVisible = false;
    }
  }
  
  public changeRow() {
    if (!this.closeCard) {
      const tab = Metadata.getInstance<Tabs>('tabPratos');
      let grid: GridEditable;
      let text: RichText;
      if (tab.activeTab === 2) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadrao');
        text = Metadata.getInstance<RichText>('TXPREPPRAT');
        grid.editing = true;
        // tratamento para o valor component.content vir atualizado
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPPRAT, 'TXPREPPRAT', text.content);
          // grid.datasource.currentRow.TXPREPPRAT = component.content;
          // grid.updateRow(grid.datasource.currentRow);
        }, 500);
      } else if (tab.activeTab === 3) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoTipoCard');
        text = Metadata.getInstance<RichText>('TXPREPTPCARD');
        grid.editing = true;
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPTPCARD, 'TXPREPTPCARD', text.content);
        }, 500);
      } else if (tab.activeTab === 4) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoLocal');
        text = Metadata.getInstance<RichText>('TXPREPFILI');
        grid.editing = true;
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPFILI, 'TXPREPFILI', text.content);
        }, 500);
      } else if (tab.activeTab === 5) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoServico');
        text = Metadata.getInstance<RichText>('TXPREPSERV');
        grid.editing = true;
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPSERV, 'TXPREPSERV', text.content);
        }, 500);
      } else if (tab.activeTab === 6) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoPadraoQualidade');
        text = Metadata.getInstance<RichText>('TXPREPPADQ');
        grid.editing = true;
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPPRAPADQUALI, 'TXPREPPADQ', text.content);
        }, 500);
      } else if (tab.activeTab === 7) {
        grid = Metadata.getInstance<GridEditable>('gridModoPreparoRegiao');
        text = Metadata.getInstance<RichText>('TXPREPREGIAO');
        grid.editing = true;
        setTimeout(() => {
          grid.updateCell(grid.datasource.currentRow.NRPREPPRAREGIAO, 'TXPREPREGIAO', text.content);
        }, 500);
      }
      
      this.activeEditing();
    } else {
      this.cancelEditing();
    }
  }
  
  public closeCardText({ component }: IEventParam<Button>) {
    this.closeCard = true;
    // const card = Metadata.getInstance<Card>('prodCard');
    const card = component.parent?.parent as Card;
    card.isVisible = false;
    this.cardTextIsVisible = false;
  }
}
