import {
  Loader, Metadata, IEventParam, IDictionary, Config,
} from '@zeedhi/core';
import {
  Form, Select, Button,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme01800ConsumoPlanejadoRealizadoController {
  public reportController = Loader.getInstance('ReportController');

  public appController = Loader.getInstance('AppController');

  public utilities = Loader.getInstance('Utilities');
  
  public modalController = Loader.getInstance('ModalController');

  public defaultReport({ component }: IEventParam<Select>) {
    component.setValue(component.datasource.data[0]);
  }
  
  public setFilterServ({ component }: IEventParam<Select>) {
    const tipoCard = Metadata.getInstance<Select>('TIPOCARD');
    let tpCardValue = '';
    if (tipoCard.returnObject) tpCardValue = tipoCard.value ? tipoCard.value.CDTIPOCARD : '';
    else tpCardValue = tipoCard.value ? tipoCard.value : '';

    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: tpCardValue.toString(),
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }

  public generateReport({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('FORM');

    if (this.utilities.centralIsValid() && this.formIsValid(form)) {
      const row: IDictionary = form.value;
      
      this.setParams(row);
      if (row.CDFILCENTPME == null) this.utilities.showAlert('alertError', 'Central não informada.', 'error');
      
      /* const dtFinMax = moment(row.DTDE, 'DD/MM/YYYY').add(15, 'd');
      if ((row.GRUPFILI == null && row.UNIDADE.length === 0 && row.GRUPOSERVICO == null && row.SERVICO.length === 0)
          || (row.DTDE !== row.DTATE && moment(row.DTATE, 'DD/MM/YYYY') > dtFinMax)) {
        DialogService.show({
          name: 'confirmReport',
          type: 'warning',
          title: 'Atenção',
          text: 'Caso não seja definido opções de filtro ou informar um período superior a 15 '+
          'dias o processamento pode demorar. Deseja continuar?',
          buttons: [
            {
              name: 'yes',
              component: 'ZdButton',
              label: 'Sim',
              events: { click: () => this.reportController.callGenerateReport(component, row, 'report/consumoPlanReal') },
              outline: true,
            },
            {
              name: 'no',
              component: 'ZdButton',
              label: 'Não',
              events: { click: () => DialogService.hide() },
            },
            {
              name: 'progressLine',
              component: 'ZdProgress',
              label: 'Progress',
              indeterminate: true,
              cssClass: 'loading-progress-line',
            },
          ],
        });
      */
      else {
        this.reportController.callGenerateReport(component, row, 'report/consumoPlanReal');
      }
    }
  }
  
  private setParams(row: IDictionary) {
    const maskProd: string = (Config.masks.productMask as PmeMask).pattern;
    row.LISTASERV = '';
    row.CDSERVFILI = row.SERVICO ? row.SERVICO : null;
    row.UNIDADE = row.UNIDADE ? row.UNIDADE : null;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
    row.TAMACNIVEL = this.utilities.calcTamacNivel(row.NIVEL, 'produto');
    row.TAMCODIGO = '';
    row.CDPICTPROD = this.utilities.formatReportMask(maskProd);
    row.AGRUPMASK = this.utilities.getReportMaskNivel(maskProd, row.NIVEL);
    row.DIFPERCENT = row.DIFPERCENT ? row.DIFPERCENT : 0;
  }

  private formIsValid(form: Form) {
    let valid = false;
    const row: IDictionary = form.value;
    if (this.utilities.centralIsValid() && form.validate()) {
      if (this.utilities.dateIsValid(row.DTDE, row.DTATE)) {
        valid = true;
      } else this.utilities.showAlert('alertError', 'Data Inicial deve ser menor que a data final.', 'error');
    }
    return valid;
  }
  
  public clearFields() {
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    unidade.setValue('');
  }
}
